@@ -25,24 +25,10 @@ fi
 
 OUTPUT=${CHART_HOME}/output
 OUTPUT_BIN=${OUTPUT}/bin
-PULSARCTL_VERSION=v2.9.2.7
+PULSARCTL_VERSION=v3.0.2.6
 PULSARCTL_BIN=${HOME}/.pulsarctl/pulsarctl
 export PATH=${HOME}/.pulsarctl/plugins:${PATH}
 
-discoverArch() {
-  ARCH=$(uname -m)
-  case $ARCH in
-    x86) ARCH="386";;
-    x86_64) ARCH="amd64";;
-    i686) ARCH="386";;
-    i386) ARCH="386";;
-    arm64) ARCH="arm64";;
-  esac
-}
-
-discoverArch
-OS=$(echo `uname`|tr '[:upper:]' '[:lower:]')
-
 test -d "$OUTPUT_BIN" || mkdir -p "$OUTPUT_BIN"
 
 function pulsar::verify_pulsarctl() {
@@ -62,6 +48,4 @@ function pulsar::ensure_pulsarctl() {
     curl --retry 10 -L -o $install_script https://raw.githubusercontent.com/streamnative/pulsarctl/master/install.sh
     chmod +x $install_script
     $install_script --user --version ${PULSARCTL_VERSION}
-}
-
-
+}
\ No newline at end of file
